PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-07-13-15:08:48','2023-07-13-15:11:13',1689253728,1689253873,'month',1,0,39,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(2,'2023-07-13-15:11:13','2023-07-13-15:12:39',1689253873,1689253959,'month',1,0,39,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(3,'2023-07-13-15:12:39','2023-07-13-15:28:15',1689253959,1689254895,'month',1,0,39,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(4,'2023-07-13-15:28:15','2023-07-14-11:48:01',1689254895,1689328081,'month',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(5,'2023-07-14-11:48:01','2023-07-14-13:32:38',1689328081,1689334358,'month',1,1,39,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(6,'2023-07-14-13:32:39','2023-07-14-13:34:22',1689334359,1689334462,'month',1,0,41,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "TEST_PROCESSORS": 999999999, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(7,'2023-07-14-13:34:22','2023-07-14-13:43:47',1689334462,1689335027,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(8,'2023-07-14-13:43:47','2023-07-14-13:45:29',1689335027,1689335129,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(9,'2023-07-14-13:45:29','2023-07-14-13:47:34',1689335129,1689335254,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_%TEST_PROCESSORS%": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_%TEST_PROCESSORS%": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_%TEST_PROCESSORS%": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_%TEST_PROCESSORS%": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(10,'2023-07-14-13:47:34','2023-07-14-13:51:54',1689335254,1689335514,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(11,'2023-07-14-13:51:54','2023-07-14-14:13:12',1689335514,1689336792,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "DEPENDENT": "%^INDEPENDENT%", "INDEPENDENT": "strongscaling", "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(12,'2023-07-14-14:13:12','2023-07-14-15:45:46',1689336792,1689342346,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "DEPENDENT": "%^INDEPENDENT%", "INDEPENDENT": "strongscaling", "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(13,'2023-07-14-15:45:46','2023-07-14-15:48:48',1689342346,1689342528,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "DEPENDENT": "%^INDEPENDENT%", "INDEPENDENT": "strongscaling", "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(14,'2023-07-14-15:48:48','2023-07-14-15:48:48',1689342528,0,'month',1,0,43,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "TEST_PROCESSORS": 999999999, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 96}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 192}, "SCALABILITY_768": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 768}, "SCALABILITY_1024": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 1024}, "SCALABILITY_999999999": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": 48}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_999999999": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_768": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "TRACE_1024": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "OSU_RUN_999999999": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_999999999": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": 48, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling", "STRONGSCALING_PROCS": [48, 96, 192]}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "DEPENDENT": "strongscaling", "INDEPENDENT": "strongscaling", "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00s", "PROJDIR": "/home/dbeltran/new_autosubmit/a00s/proj/project_files", "DEFAULT": {"EXPID": "a67k", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00s/proj/auto-performance-profiling/autosubmit/configuration/common,/home/dbeltran/new_autosubmit/a00s/proj/project_files/autosubmit/configuration/preset-1", "POST": "~/platforms_credentials.yml"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a00s_CLEAN','2023-07-14-11:48:19','2023-07-14-11:48:34',1689328099,1689328099,1689328099,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,1,'MARENOSTRUM0',339377,'',0,5,0.0,0.0,'a00s_CLEAN.20230714114834.out','a00s_CLEAN.20230714114834.err',5,'a00s_REMOTE_SETUP','');
INSERT INTO job_data VALUES(2,0,'a00s_REMOTE_SETUP','2023-07-14-11:48:39','2023-07-14-11:48:39',1689328119,0,0,'SUBMITTED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,1,'MARENOSTRUM0',341212,'',0,5,0.0,0.0,'','',0,'a00s_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00s_20210811_WeakScaling_REMOTE_INIDATA,a00s_20210811_CompilationEfficiency_REMOTE_INIDATA,a00s_20210811_StrongScaling_REMOTE_INIDATA','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',14);
INSERT INTO sqlite_sequence VALUES('job_data',2);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
